==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/CommandLineOptions/StatusOption/translations/status_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>StatusOption</name>
    <message>
        <location filename="../statusoption.cpp" line="39"/>
        <source>Print playback status</source>
        <translation>Показати статус відтворення</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="41"/>
        <source>Print formatted track name (example: qmmp --nowplaying &quot;%t - %a&quot;)</source>
        <translation>Показати форматовану назву композиції (приклад: qmmp --nowplaying &quot;%t - %a&quot;)</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="42"/>
        <source>Print --nowplaying syntax</source>
        <translation>Показати синтаксис команди --nowplaying</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="87"/>
        <source>Syntax:</source>
        <translation>Синтаксис:</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="88"/>
        <source>%p - artist</source>
        <translation>%p - виконавець</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="89"/>
        <source>%a - album</source>
        <translation>%a - альбом</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="90"/>
        <source>%aa - album artist</source>
        <translation>%aa - альбом виконавець</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="91"/>
        <source>%t - title</source>
        <translation>%t - назва</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="92"/>
        <source>%n - track</source>
        <translation>%n - номер трека</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="93"/>
        <source>%NN - 2-digit track</source>
        <translation>%NN - 2-розрядний номер трека</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="94"/>
        <source>%g - genre</source>
        <translation>%g - жанр</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="95"/>
        <source>%c - comment</source>
        <translation>%c - коментар</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="96"/>
        <source>%C - composer</source>
        <translation>%С - композитор</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="97"/>
        <source>%D - disc number</source>
        <translation>%D - номер диска</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="98"/>
        <source>%f - file name</source>
        <translation>%f - ім&apos;я файла</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="99"/>
        <source>%F - full path</source>
        <translation>%F - повний шлях</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="100"/>
        <source>%y - year</source>
        <translation>%y - рік</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="101"/>
        <source>%l - duration</source>
        <translation>%l - тривалість</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="102"/>
        <source>%if(A&amp;B&amp;C,D,E) - condition</source>
        <translation>%if(A&amp;B&amp;C,D,E) - умова</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="103"/>
        <source>%dir(n) - directory name located on n levels above</source>
        <translation>%dir(n) - ім&apos;я теки на n рівнів вище</translation>
    </message>
</context>
</TS>

==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/CommandLineOptions/StatusOption/translations/status_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>StatusOption</name>
    <message>
        <location filename="../statusoption.cpp" line="30"/>
        <source>Print playback status</source>
        <translation>Показати статус відтворення</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="31"/>
        <source>Print formatted track name (example: qmmp --nowplaying &quot;%t - %a&quot;)</source>
        <translation>Показати форматовану назву композиції (приклад: qmmp --nowplaying &quot;%t - %a&quot;)</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="33"/>
        <source>Print --nowplaying syntax</source>
        <translation>Показати синтаксис команди --nowplaying</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="94"/>
        <source>Syntax:</source>
        <translation>Синтаксис:</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="95"/>
        <source>%p - artist</source>
        <translation>%p - виконавець</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="96"/>
        <source>%a - album</source>
        <translation>%a - альбом</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="97"/>
        <source>%aa - album artist</source>
        <translation>%aa - альбом виконавець</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="98"/>
        <source>%t - title</source>
        <translation>%t - назва</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="99"/>
        <source>%n - track</source>
        <translation>%n - номер трека</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="100"/>
        <source>%NN - 2-digit track</source>
        <translation>%NN - 2-розрядний номер трека</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="101"/>
        <source>%g - genre</source>
        <translation>%g - жанр</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="102"/>
        <source>%c - comment</source>
        <translation>%c - коментар</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="103"/>
        <source>%C - composer</source>
        <translation>%С - композитор</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="104"/>
        <source>%D - disc number</source>
        <translation>%D - номер диска</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="105"/>
        <source>%f - file name</source>
        <translation>%f - ім&apos;я файла</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="106"/>
        <source>%F - full path</source>
        <translation>%F - повний шлях</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="107"/>
        <source>%y - year</source>
        <translation>%y - рік</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="108"/>
        <source>%l - duration</source>
        <translation>%l - тривалість</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="109"/>
        <source>%{bitrate} - bitrate</source>
        <translation>%{bitrate} - бітрейт</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="110"/>
        <source>%{samplerate} - sample rate</source>
        <translation>%{samplerate} - частота</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="111"/>
        <source>%{channels} - number of channels</source>
        <translation>%{channels} - кількість каналів</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="112"/>
        <source>%{samplesize} - bits per sample</source>
        <translation>%{samplesize} - біт на семпл</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="113"/>
        <source>%{format} - format name</source>
        <translation>%{format} - формат</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="114"/>
        <source>%{decoder} - decoder name</source>
        <translation>%{decoder} - декодер</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="115"/>
        <source>%{filesize} - file size</source>
        <translation>%{filesize} - розмір</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="116"/>
        <source>%if(A&amp;B&amp;C,D,E) - condition</source>
        <translation>%if(A&amp;B&amp;C,D,E) - умова</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="117"/>
        <source>%dir(n) - directory name located on n levels above</source>
        <translation>%dir(n) - ім&apos;я теки на n рівнів вище</translation>
    </message>
</context>
</TS>
